// mixins.less

// vendor
@import "vendor/_rfs";

// deprecate
@import "mixins/_deprecate";

// utilities
@import "mixins/_breakpoints";
@import "mixins/_hover";
@import "mixins/_image";
@import "mixins/_badge";
@import "mixins/_resize";
@import "mixins/_screen-reader";
@import "mixins/_size";
@import "mixins/_reset-text";
@import "mixins/_text-emphasis";
@import "mixins/_text-hide";
@import "mixins/_text-truncate";
@import "mixins/_visibility";
@import "mixins/_widget";

// components
@import "mixins/_alert";
@import "mixins/_buttons";
@import "mixins/_caret";
@import "mixins/_pagination";
@import "mixins/_lists";
@import "mixins/_list-group";
@import "mixins/_nav-divider";
@import "mixins/_forms";
@import "mixins/_table-row";
@import "mixins/_widget";

// skins
@import "mixins/_background-variant";
@import "mixins/_border-radius";
@import "mixins/_box-shadow";
@import "mixins/_gradients";
@import "mixins/_transition";

// layout
@import "mixins/_clearfix";
@import "mixins/_grid-framework";
@import "mixins/_grid";
@import "mixins/_float";
