div.btns {
  width: auto;
  vertical-align: middle;
  padding: 5px 0px 5px 0px;
  clear: both;
}
div.btns:after {
  content: '';
  display: block;
  clear: both;
}
div.btns div.left {
  /* secondary (float left) */
  width: auto;
  float: left;
}
div.btns div.right {
  /* secondary (float right) */
  width: auto;
  float: right;
}
div.btns div.secondary {
  /* secondary gray (left padding) */
  width: auto;
  float: left;
  padding: 0 0 0 25px;
}
div.btns div.gray {
  /* secondary gray (no padding) */
  width: auto;
  float: left;
  padding: 0;
}
div.btns div.btn,
div.btns div.link {
  min-height: 25px;
  line-height: 25px;
  width: auto;
  cursor: pointer !important;
  margin: 0px 5px 0px 0px;
  padding: 0;
  float: left;
}
div.btns div.btn a,
div.btns div.btn input,
div.btns div.btn button,
div.btns div.link a,
div.btns div.link input,
div.btns div.link button {
  /* size, font, block */
  min-height: 25px;
  line-height: 25px;
  font-size: 1rem;
  font-family: Verdana, Arial, Helvetica, sans-serif;
  cursor: pointer !important;
  border: none;
  display: inline-block;
  overflow: visible;
  margin: 0;
  padding: 0px 10px 0px 10px;
}
div.btns div.btn {
  color: #fff;
  background-color: #007bff;
}
div.btns div.btn a,
div.btns div.btn input,
div.btns div.btn button {
  /* render as button */
  color: #fff;
  background-color: #007bff;
  cursor: pointer !important;
}
div.btns div.btn a:hover,
div.btns div.btn input:hover,
div.btns div.btn button:hover {
  text-decoration: none !important;
  color: #fff;
  background-color: #007bff;
}
div.btns div.gray div.btn,
div.btns div.right div.btn,
div.btns div.secondary div.btn {
  color: #000;
  background-color: #adb5bd;
}
div.btns div.gray div.btn a,
div.btns div.right div.btn a,
div.btns div.secondary div.btn a,
div.btns div.gray div.btn input,
div.btns div.right div.btn input,
div.btns div.secondary div.btn input,
div.btns div.gray div.btn button,
div.btns div.right div.btn button,
div.btns div.secondary div.btn button {
  color: #000;
  background-color: #adb5bd;
}
div.btns div.gray div.btn a:hover,
div.btns div.right div.btn a:hover,
div.btns div.secondary div.btn a:hover,
div.btns div.gray div.btn input:hover,
div.btns div.right div.btn input:hover,
div.btns div.secondary div.btn input:hover,
div.btns div.gray div.btn button:hover,
div.btns div.right div.btn button:hover,
div.btns div.secondary div.btn button:hover {
  text-decoration: none !important;
  color: #000;
  background-color: #adb5bd;
}
div.btns div.link input,
div.btns div.link button {
  /* render as link */
  color: #007bff;
  background-color: #fff;
  border: 0;
}
div.btns div.link input:hover,
div.btns div.link button:hover {
  text-decoration: none !important;
  color: #007bff;
  background-color: #fff;
}
form div.inline div.left {
  /* widget inline padding */
  padding-left: 155px;
}
/* IE7 */
*:first-child + html form div.btns div.btn {
  padding: 0px 0px 2px 0px;
}
.ddslick-widget .dd-container {
  position: relative;
  outline: none;
}
.ddslick-widget .dd-select {
  position: relative;
  height: calc(1.5em + 0.75rem + 2px);
  line-height: calc(1.5em + 0.75rem + 2px);
  background-color: #FFFFFF;
  border: 1px solid #ced4da;
  cursor: pointer;
  outline: none;
}
.ddslick-widget .dd-desc {
  display: inline-block;
  overflow: hidden;
  line-height: 1.4em;
}
.ddslick-widget .dd-selected {
  width: 100%;
  height: calc(calc(1.5em + 0.75rem + 2px) + 2px);
  line-height: calc(calc(1.5em + 0.75rem + 2px) + 2px);
  text-align: left;
  position: relative;
  display: block;
  padding: 0 10px;
  overflow: hidden;
  border: 0;
  color: #212529;
  background-color: #FFFFFF;
  outline: none;
}
.ddslick-widget .dd-selected:focus {
  z-index: 2001;
}
.ddslick-widget .dd-pointer {
  width: 0;
  height: 0;
  position: absolute;
  right: 10px;
  top: 50%;
  margin-top: -3px;
}
.ddslick-widget .dd-selected:focus + .dd-pointer {
  z-index: 2002;
}
.ddslick-widget .dd-pointer-down {
  border: solid 5px transparent;
  border-top: solid 5px #000;
}
.ddslick-widget .dd-pointer-up {
  border: solid 5px transparent !important;
  border-bottom: solid 5px #000 !important;
  margin-top: -8px;
}
.ddslick-widget .dd-options {
  border: solid 1px #ced4da;
  border-top: none;
  list-style: none;
  display: none;
  position: absolute;
  z-index: 2000;
  margin: 0;
  padding: 0;
  background: #fff;
  height: 250px;
  overflow: visible;
  overflow-x: hidden;
  outline: none;
}
.ddslick-widget .dd-options .dd-option {
  padding: 5px 10px;
  display: block;
  width: 100%;
  text-align: left;
  border-bottom: solid 1px #ced4da;
  overflow: visible;
  text-decoration: none;
  color: #212529;
  background-color: #FFFFFF;
  cursor: pointer;
  -webkit-transition: all 0.25s ease-in-out;
  -moz-transition: all 0.25s ease-in-out;
  -o-transition: all 0.25s ease-in-out;
  -ms-transition: all 0.25s ease-in-out;
  box-sizing: border-box;
}
.ddslick-widget .dd-options .dd-option-text {
  display: block;
}
.ddslick-widget .dd-options .dd-option-description {
  display: block;
}
.ddslick-widget .dd-options .dd-option:hover,
.ddslick-widget .dd-options .dd-option:active,
.ddslick-widget .dd-options .dd-option:focus {
  z-index: 2001;
}
.ddslick-widget .dd-options .dd-option-selected {
  color: #FFFFFF;
  background-color: #007bff;
}
.ddslick-widget .dd-options .dd-option-image,
.ddslick-widget .dd-options .dd-selected-image {
  vertical-align: middle;
  float: left;
  margin-right: 5px;
  max-width: 64px;
}
.ddslick-widget .dd-options .dd-image-right {
  float: right;
  margin-right: 15px;
  margin-left: 5px;
}
.ddslick-widget .dd-options > .dd-option:last-child {
  border-bottom: none;
}
.ddslick-widget .dd-selected-description-truncated {
  text-overflow: ellipsis;
  white-space: nowrap;
}
.j01-dropdown {
  width: 100%;
  position: relative;
  display: inline-block;
  vertical-align: bottom;
  line-height: 1;
  border: 1px solid #dee2e6;
}
.j01-dropdown a {
  text-decoration: none;
}
.j01-dropdown .dropdown-toggle {
  width: 100%;
  background: #fff;
  display: inline-block;
  text-decoration: none;
  position: relative;
  font-size: 1rem;
  line-height: 32px;
  padding: 0 6px 0 6px;
  margin: 0;
}
.j01-dropdown .dropdown-toggle .dropdown-icon {
  height: 8px;
  width: 8px;
  position: absolute;
  top: 14px;
  right: 20px;
  color: #000;
  opacity: 0.6;
  display: inline-block;
}
.j01-dropdown .dropdown-toggle .dropdown-icon:after {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-top: 8px solid;
}
.j01-dropdown .dropdown-toggle .dropdown-text {
  color: #495057;
  display: inline-block;
  vertical-align: middle;
}
.j01-dropdown .dropdown-toggle img {
  vertical-align: middle;
}
.j01-dropdown .dropdown-menu-wrapper {
  background: #fff;
  overflow: hidden;
  border-right: 1px solid #dee2e6;
  border-bottom: 1px solid #dee2e6;
  border-left: 1px solid #dee2e6;
}
.j01-dropdown .dropdown-menu-container {
  position: relative;
  width: 300px;
  max-width: 100%;
}
.j01-dropdown .dropdown-menu {
  display: none;
  position: absolute;
  top: 0;
  left: 0;
  width: inherit;
}
.j01-dropdown .dropdown-menu-main,
.j01-dropdown .dropdown-menu-open {
  display: block;
}
.j01-dropdown .dropdown-menu-open {
  position: relative;
}
.j01-dropdown .dropdown-menu-wrapper {
  position: absolute;
  z-index: 999;
  display: none;
  opacity: 0;
}
.j01-dropdown .dropdown-below .dropdown-menu-wrapper {
  top: 100%;
  bottom: auto;
  margin: 3px 0 0;
}
.j01-dropdown .dropdown-above .dropdown-menu-wrapper {
  bottom: 100%;
  top: auto;
  margin: 0 0 3px;
}
.j01-dropdown .dropdown-mask {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 100;
  display: none;
}
.j01-dropdown .dropdown-animating .dropdown-mask {
  display: block;
}
.j01-dropdown .dropdown-overlay {
  background: rgba(0, 0, 0, 0.5);
  position: fixed;
  opacity: 0;
}
.j01-dropdown .dropdown-header {
  position: relative;
  min-height: 25px;
  padding: 12.5px 50px;
  margin: 0;
  border-bottom: 1px solid #ccc;
}
.j01-dropdown .dropdown-menu-main .dropdown-header {
  display: none;
}
.j01-dropdown .dropdown-title {
  font-size: 1rem;
  text-align: center;
  line-height: 25px;
  padding: 0;
  margin: 0;
}
.j01-dropdown .dropdown-close,
.j01-dropdown .dropdown-back {
  position: absolute;
  text-decoration: none;
  top: 0;
  color: #aaa;
  font-size: 2rem;
  font-weight: bold;
  width: 50px;
  height: 50px;
  line-height: 50px;
  text-align: center;
}
.j01-dropdown .dropdown-close .dropdown-text,
.j01-dropdown .dropdown-back .dropdown-text {
  display: none;
}
.j01-dropdown .dropdown-back {
  left: 0;
}
.j01-dropdown .dropdown-back .dropdown-icon:after {
  content: '';
  display: inline-block;
  width: 0;
  height: 0;
  border-top: 4px solid transparent;
  border-bottom: 4px solid transparent;
  border-right: 4px solid;
}
.j01-dropdown .dropdown-menu-main .dropdown-back {
  display: none;
}
.j01-dropdown .dropdown-close {
  display: none;
  right: 0;
}
.j01-dropdown .dropdown-close .dropdown-icon:after {
  font-family: sans-serif;
  content: '\00d7';
}
.j01-dropdown .dropdown-list,
.j01-dropdown .dropdown-item {
  list-style-type: none;
  font-size: inherit;
}
.j01-dropdown .dropdown-list {
  overflow: hidden;
  text-align: left;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
  margin: 0;
  padding: 0;
}
.j01-dropdown .dropdown-item {
  padding: 0;
  margin: 0 0 1px;
}
.j01-dropdown .dropdown-item:last-child {
  margin-bottom: 0;
}
.j01-dropdown .dropdown-label {
  color: #495057;
  font-weight: bold;
  font-size: -2rem;
  padding: 10px 20px;
  margin: 20px 0 0;
}
.j01-dropdown .dropdown-label:first-child {
  margin-top: 0;
}
.j01-dropdown .dropdown-divider {
  border-bottom: 1px solid #dee2e6;
  margin: 10px 0;
}
.j01-dropdown .dropdown-divider:first-child,
.j01-dropdown .dropdown-divider:last-child {
  display: none;
}
.j01-dropdown .dropdown-divider + .dropdown-label {
  margin-top: 10px;
}
.j01-dropdown .dropdown-divider:first-child + .dropdown-label {
  margin-top: 0;
}
.j01-dropdown .dropdown-link {
  display: block;
  position: relative;
  font-size: 1rem;
  text-decoration: none;
  padding: 10px 20px;
}
.j01-dropdown .dropdown-parent .dropdown-link:after {
  content: '';
  opacity: 0.6;
  position: absolute;
  right: 20px;
  top: 50%;
  margin-top: -4px;
  display: inline-block;
  vertical-align: middle;
  border-left: 4px solid;
  border-bottom: 4px solid transparent;
  border-top: 4px solid transparent;
}
.j01-dropdown .dropdown-link:hover {
  background: rgba(0, 0, 0, 0.03);
  color: #0d659b;
}
.j01-dropdown .dropdown-focused .dropdown-link {
  background: rgba(0, 0, 0, 0.03);
  color: #0d659b;
}
.j01-dropdown .dropdown-selected .dropdown-link {
  background: #007bff;
  color: #ffffff;
}
@media screen and (max-width: 600px) {
  .j01-dropdown .dropdown-overlay {
    z-index: -1;
    transition: opacity 0.2s linear;
  }
  .j01-dropdown .dropdown-opening .dropdown-overlay,
  .j01-dropdown .dropdown-open .dropdown-overlay {
    z-index: 101;
    opacity: 1;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
  }
  .j01-dropdown .dropdown-menu-wrapper {
    width: auto !important;
    height: auto !important;
    position: fixed !important;
    top: 10px;
    bottom: 10px;
    left: 10px;
    right: 10px;
    margin: 0;
    border: 0;
  }
  .j01-dropdown .dropdown-above .dropdown-menu-wrapper,
  .j01-dropdown .dropdown-below .dropdown-menu-wrapper {
    top: 10px;
    bottom: 10px;
    margin: 0;
  }
  .j01-dropdown .dropdown-menu-container {
    width: 100%;
  }
  .j01-dropdown .dropdown-menu-main .dropdown-header {
    display: block;
  }
  .j01-dropdown .dropdown-close {
    display: block;
  }
}
@media all and (min-width: 601px) {
  .j01-dropdown .dropdown-overlay {
    display: none !important;
  }
}
/*---[ form control ]---------------------------------------------------------*/
.form-control {
  display: block;
  width: 100%;
  height: calc(1.5em + 0.75rem + 2px);
  padding: 0.375rem 0.75rem;
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  color: #495057;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #ced4da;
  border-radius: 0.25rem;
  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}
@media (prefers-reduced-motion: reduce) {
  .form-control {
    transition: none;
  }
}
.form-control::-ms-expand {
  background-color: transparent;
  border: 0;
}
.form-control:-moz-focusring {
  color: transparent;
  text-shadow: 0 0 0 #495057;
}
.form-control:focus {
  color: #495057;
  background-color: #fff;
  border-color: #80bdff;
  outline: 0;
  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
}
.form-control::placeholder {
  color: #6c757d;
  opacity: 1;
}
.form-control:disabled,
.form-control[readonly] {
  background-color: #e9ecef;
  opacity: 1;
}
select.form-control:focus::-ms-value {
  color: #495057;
  background-color: #fff;
}
/*---[ radio, checkbox widget]------------------------------------------------*/
.radio,
.checkbox {
  margin-top: 0;
}
.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  margin-top: 1px \9;
}
.radio + .radio,
.checkbox + .checkbox {
  margin-top: -5px;
}
/*---[ multi widget]----------------------------------------------------------*/
.multi-control-widget {
  padding-bottom: 10px;
}
.multi-control-widget::after {
  display: block;
  clear: both;
  content: "";
}
.multi-control-widget .multi-control-checkbox {
  float: left;
}
.multi-control-widget .multi-control-input {
  margin-left: 25px;
}
/*---[ sizing ]---------------------------------------------------------------*/
select.form-control[size],
select.form-control[multiple] {
  height: auto;
}
textarea.form-control {
  height: auto;
}
.form-group {
  margin-bottom: 1rem;
}
.form-text {
  display: block;
  margin-top: 0.25rem;
}
/*---[ addon ]----------------------------------------------------------------*/
.input-group.input-group-before .form-control {
  border-left: 0;
}
.input-group.input-group-before .input-group-addon:first-child {
  background-color: #e9ecef;
}
.input-group.input-group-after .form-control {
  border-right: 0;
}
.input-group.input-group-after .input-group-addon:last-child {
  background-color: #fff;
}
/*---[ errors ]---------------------------------------------------------------*/
.widget-error {
  position: relative;
}
.widget-error .help-block,
.widget-error .radio,
.widget-error .checkbox,
.widget-error .radio-inline,
.widget-error .checkbox-inline {
  color: #dc3545;
}
.widget-error .form-control {
  border-color: #dc3545;
}
.widget-error .input-group-addon {
  color: #dc3545;
  border-color: #dc3545;
  background-color: #fff;
}
.widget-error .control-error {
  color: #dc3545;
}
.widget-error .select2-container .select2-choice,
.widget-error .select2-container-multi .select2-choices {
  border: 1px solid #dc3545;
}
/*---[ display mode ]---------------------------------------------------------*/
.widget-display .form-control {
  color: #212529;
  background-color: transparent;
  border: 0;
}
.input-group {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  align-items: stretch;
  width: 100%;
}
.input-group > .form-control,
.input-group > .form-control-plaintext,
.input-group > .custom-file {
  position: relative;
  flex: 1 1 0%;
  min-width: 0;
  margin-bottom: 0;
}
.input-group > .form-control + .form-control,
.input-group > .form-control-plaintext + .form-control,
.input-group > .custom-file + .form-control,
.input-group > .form-control + .custom-file,
.input-group > .form-control-plaintext + .custom-file,
.input-group > .custom-file + .custom-file {
  margin-left: -1px;
}
.input-group > .form-control:focus {
  z-index: 3;
}
.input-group > .form-control:not(:last-child) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.input-group > .form-control:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.input-group-prepend,
.input-group-append {
  display: flex;
}
.input-group-prepend .btn,
.input-group-append .btn {
  position: relative;
  z-index: 2;
}
.input-group-prepend .btn:focus,
.input-group-append .btn:focus {
  z-index: 3;
}
.input-group-prepend .btn + .btn,
.input-group-append .btn + .btn,
.input-group-prepend .btn + .input-group-text,
.input-group-append .btn + .input-group-text,
.input-group-prepend .input-group-text + .input-group-text,
.input-group-append .input-group-text + .input-group-text,
.input-group-prepend .input-group-text + .btn,
.input-group-append .input-group-text + .btn {
  margin-left: -1px;
}
.input-group-prepend {
  margin-right: -1px;
}
.input-group-append {
  margin-left: -1px;
}
.input-group-text {
  display: flex;
  align-items: center;
  padding: 0.375rem 0.75rem;
  margin-bottom: 0;
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  color: #495057;
  text-align: center;
  white-space: nowrap;
  background-color: #e9ecef;
  border: 1px solid #ced4da;
  border-radius: 0.25rem;
}
.input-group-text input[type="radio"],
.input-group-text input[type="checkbox"] {
  margin-top: 0;
}
.input-group-lg > .form-control:not(textarea) {
  height: calc(1.5em + 1rem + 2px);
}
.input-group-lg > .form-control,
.input-group-lg > .input-group-prepend > .input-group-text,
.input-group-lg > .input-group-append > .input-group-text,
.input-group-lg > .input-group-prepend > .btn,
.input-group-lg > .input-group-append > .btn {
  padding: 0.5rem 1rem;
  font-size: 1.25rem;
  line-height: 1.5;
  border-radius: 0.3rem;
}
.input-group-sm > .form-control:not(textarea),
.input-group-sm > .custom-select {
  height: calc(1.5em + 0.5rem + 2px);
}
.input-group-sm > .form-control,
.input-group-sm > .input-group-prepend > .input-group-text,
.input-group-sm > .input-group-append > .input-group-text,
.input-group-sm > .input-group-prepend > .btn,
.input-group-sm > .input-group-append > .btn {
  padding: 0.25rem 0.5rem;
  font-size: 0.875rem;
  line-height: 1.5;
  border-radius: 0.2rem;
}
.input-group > .input-group-prepend > .btn,
.input-group > .input-group-prepend > .input-group-text,
.input-group > .input-group-append:not(:last-child) > .btn,
.input-group > .input-group-append:not(:last-child) > .input-group-text,
.input-group > .input-group-append:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group > .input-group-append:last-child > .input-group-text:not(:last-child) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.input-group > .input-group-append > .btn,
.input-group > .input-group-append > .input-group-text,
.input-group > .input-group-prepend:not(:first-child) > .btn,
.input-group > .input-group-prepend:not(:first-child) > .input-group-text,
.input-group > .input-group-prepend:first-child > .btn:not(:first-child),
.input-group > .input-group-prepend:first-child > .input-group-text:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.picker-element {
  opacity: 0;
  position: absolute;
  transition: none;
  z-index: -1;
}
.no-touch .picker-element {
  left: -99999px;
}
.picker {
  cursor: pointer;
  margin: 0;
  overflow: hidden;
}
.picker .picker-label {
  color: #212529;
  cursor: pointer;
  display: block;
  float: left;
  font-size: 1rem;
  line-height: 1.5;
  user-select: none;
  padding: 0;
}
.picker .picker-handle {
  border: 0 solid #ced4da;
  display: block;
  float: left;
  margin: 0 5px 0 0;
}
.no-touch .picker:hover .picker-label {
  color: #212529;
}
.no-touch .picker:hover .picker-handle {
  border-color: #ced4da;
}
.picker.focus .picker-label {
  color: #212529;
}
.picker.focus .picker-handle {
  border-color: #ced4da;
}
.picker.picker-radio .picker-handle {
  border: 0;
  border-radius: 4px;
  margin: 0 5px 0 0;
}
.picker.picker-radio .picker-flag {
  border: 1px solid #ced4da;
  border-radius: 24px;
  background: #fff;
  display: block;
  height: 24px;
  width: 24px;
  margin: 0;
}
.picker.picker-radio.focus .picker-flag {
  background: #007bff;
}
.picker.picker-radio.checked .picker-flag {
  border: 1px solid #007bff;
  background: #007bff;
}
.no-touch .picker.picker-radio:hover .picker-flag {
  background: #007bff;
}
.no-touch .picker.picker-radio.disabled:hover .picker-flag {
  background: #fff;
}
.picker.picker-checkbox .picker-handle {
  border: 0;
  border-radius: 0;
  margin: 0 5px 0 0;
}
.picker.picker-checkbox .picker-flag {
  border: 1px solid #ced4da;
  border-radius: 4px;
  background: #fff;
  display: block;
  height: 24px;
  width: 24px;
  margin: 0;
}
.picker.picker-checkbox.checked .picker-flag {
  border: 1px solid #007bff;
  background: #007bff;
}
.picker.picker-toggle {
  padding: 20px 0 0;
  position: relative;
}
.picker.picker-toggle .picker-toggle-label {
  color: #999;
  font-size: 1rem;
  position: absolute;
  text-transform: uppercase;
  top: 0;
}
.picker.picker-toggle .picker-toggle-label.on {
  color: #999;
  left: 0;
}
.picker.picker-toggle .picker-toggle-label.off {
  color: #333;
  right: 0;
}
.picker.picker-toggle .picker-label {
  display: none;
}
.picker.picker-toggle .picker-handle {
  border-radius: 0;
  height: 20px;
  position: relative;
  width: 100%;
}
.picker.picker-toggle .picker-flag {
  background: #fff;
  border-radius: 0;
  display: block;
  height: 100%;
  left: 50%;
  margin: 0px;
  position: absolute;
  top: 0;
  width: 50%;
  transition: left 0.1s linear;
}
.picker.picker-toggle.checked .picker-toggle-label.on {
  color: #333;
}
.picker.picker-toggle.checked .picker-toggle-label.off {
  color: #999;
}
.picker.picker-toggle.checked .picker-flag {
  background: #007bff;
  left: 0;
}
.picker.disabled {
  cursor: default;
  opacity: 0.5;
}
.picker.disabled .picker-label,
.picker.disabled .picker-handle {
  cursor: default;
}
.no-touch .picker.disabled:hover .picker-label {
  color: #888;
}
.no-touch .picker.disabled:hover .picker-handle {
  border-color: #ccc;
}
.radio-inline-picker-widget .picker,
.checkbox-inline-picker-widget .picker,
.single-radio-inline-picker-widget .picker,
.single-checkbox-inline-picker-widget .picker {
  display: inline-block;
  padding: 0 20px 0 0;
}
.radio-inline-picker-widget .picker label,
.checkbox-inline-picker-widget .picker label,
.single-radio-inline-picker-widget .picker label,
.single-checkbox-inline-picker-widget .picker label {
  display: block;
}
.single-radio-widget .radio,
.single-checkbox-widget .radio,
.single-radio-picker-widget .radio,
.single-checkbox-picker-widget .radio,
.single-radio-widget .checkbox,
.single-checkbox-widget .checkbox,
.single-radio-picker-widget .checkbox,
.single-checkbox-picker-widget .checkbox {
  margin-top: 0;
}
#j01FormStatus {
  background: #009dff;
  position: fixed;
  z-index: 1031;
  top: 0;
  left: 0;
  height: 4px;
  transition: all 1s;
  width: 0;
  overflow: hidden;
}
