
// Typography

#text-emphasis-variant(@parent, @color, @ignore-warning: false) {
	@{parent} {
		color: @color !important;
	}
	& when not (@emphasized-link-hover-darken-percentage = 0) {
		a@{parent} {
			#hover-focus({
				color: darken(@color, @emphasized-link-hover-darken-percentage) !important;
			});
		}
	}
	#deprecate("`#text-emphasis-variant()`", "v4.4.0", "v5", @ignore-warning);
}
