
// widget error
#widget-error(@text-color: #555; @border-color: #ccc; @background-color: #f5f5f5) {
    // Color the label and help text
    .help-block,
    .radio,
    .checkbox,
    .radio-inline,
    .checkbox-inline  {
        color: @text-color;
    }
    // Set the border and box shadow on specific inputs to match
    .form-control {
        border-color: @border-color;
//        .box-shadow(inset 0 1px 1px rgba(0,0,0,.075)); // Redeclare so transitions work
//        &:focus {
//            border-color: darken(@border-color, 10%);
//            @shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 6px lighten(@border-color, 20%);
//            .box-shadow(@shadow);
//        }
    }
    // Set validation states also for addons
    .input-group-addon {
        color: @text-color;
        border-color: @border-color;
        background-color: @background-color;
    }
    // Optional feedback icon
    .control-error {
        color: @text-color;
    }
    .select2-container .select2-choice,
    .select2-container-multi .select2-choices {
        border: 1px solid @border-color;
    }
}
